<?php
/**
 * Comments template file
 * The template for displaying Comments
 * @package Alurra
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

// Check if a password is required to continue
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="comments-area">
  <div class="comments-inner">
	<?php if ( have_comments() ) : ?>

	<h3 class="comments-title section-heading">
    <?php printf( _nx( 'One comment on &ldquo;%2$s&rdquo;', '%1$s comments on &ldquo;%2$s&rdquo;', get_comments_number(), 'comments title', 'alurra' ), number_format_i18n( get_comments_number() ), get_the_title() ); ?>
	</h3>

	<ol class="comment-list">
		<?php
			wp_list_comments( array(
				'style'      => 'ol',
				'short_ping' => true,
				'avatar_size'=> 100,
			) );
		?>
	</ol>

	<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : ?>
	<nav id="comment-nav-below" class="navigation comment-navigation" role="navigation">
		<div class="nav-previous has-accent-color-links"><?php previous_comments_link( esc_html__( '&larr; Older Comments', 'alurra' ) ); ?></div>
		<div class="nav-next has-accent-color-links"><?php next_comments_link( esc_html__( 'Newer Comments &rarr;', 'alurra' ) ); ?></div>
	</nav>
	<?php endif; ?>

	<?php if ( ! comments_open() ) : ?>
	<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'alurra' ); ?></p>
	<?php endif; ?>

	<?php endif; ?>

  <?php  
    comment_form( array(
      'comment_field' => '<p class="comment-form-comment class="col"><textarea id="comment" name="comment" cols="45" rows="5" placeholder="' . esc_attr__( 'Comment', 'alurra' ) . '" aria-required="true"></textarea></p>',
      'title_reply_before'  => '<h3 id="reply-title" class="comment-reply-title section-heading">',
      'comment_notes_after' => ' ',
      'class_form' => 'comment-form has-accent-color-links',
      'cancel_reply_link' => alurra_get_icon_svg( 'ui', 'close' ),
    ) ); 
  ?>
  </div>
</div>