<?php
/**
 * The header for our theme
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 * @package Alurra
 * @since 1.0.0
 */
 
 if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>" />
	<meta name="viewport" content="width=device-width, initial-scale=1" />
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php if ( function_exists( 'wp_body_open' ) ) {
	wp_body_open(); 
	}
?>

<div id="page" class="site">

	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'alurra' ); ?></a>
	    <div id="search-modal" class="search-modal">
		  <?php get_search_form(); ?>
		  <a href="#" id="close-search-modal" class="close-search-modal"><?php echo alurra_get_icon_svg( 'ui', 'close' ); ?></a>
		</div>
		
		<?php // action hook for any content placed before the header
		do_action ( 'alurra_before_header' );
		?>

		<?php get_template_part( 'template-parts/social-profiles' );
		
		// Get our header layout
		alurra_header_layout();
		?>	

		<?php // action hook for any content placed after the header
		do_action ( 'alurra_after_header' );
		?>
		
		<?php get_template_part( 'template-parts/sidebar', 'banner' ); ?>

		<?php // action hook for any content placed before the primary nav row
		do_action ( 'alurra_before_primary_nav' );
		?>
		
		<?php // Primary menu
			$primary_navigation = wp_nav_menu( array( 
			'theme_location'  => 'primary',
			'menu_class'      => 'nav-menu',
			'container_class' => 'menu-container',
			'echo'            => false,
			'item_spacing'    => 'discard'
		  ) ); 

		  if( $primary_navigation ) {
			printf( '<nav id="primary-navigation" class="primary-navigation"><a href="#" id="nav-toggle" class="nav-toggle">' . alurra_get_icon_svg( 'ui', 'menu' ) . '%s</a>%s</nav>', esc_html__( 'Menu', 'alurra' ), $primary_navigation ); 
		  } 
	  ?>	

		<?php // action hook for any content placed after the primary nav
		do_action ( 'alurra_before_breadcrumbs' );
		?>
		
		<?php if( !is_front_page()) {
		get_template_part( 'template-parts/sidebar', 'breadcrumbs' ); 
		}
		?>

		<?php // action hook for any content placed after the breadcrumbs
		do_action ( 'alurra_after_breadcrumbs' );
		?>
		
		<?php // action hook for any content placed before the main content
		do_action ( 'alurra_before_main_content' );
		?>
			
		<main id="main" class="site-main" role="main">	
			<div id="content" class="site-content">
		
				<?php // action hook before the site content
					do_action ( 'alurra_before_site_content' );
				?>