<?php
/**
 * Custom template tags for this theme
 * @package Alurra
 * @since 1.0.0
 */
 
 if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/* SITE BRANDING
   ==================================================== */
if ( ! function_exists( 'alurra_site_identity' ) ) :
  function alurra_site_identity() {
    if ( has_custom_logo() ) {	
		echo '<a href="' . esc_url( home_url( '/' ) ) . '" rel="home">', the_custom_logo(), '</a>';
    }

    if( esc_attr(get_theme_mod( 'alurra_show_site_title', 1 ) ) ) {
      printf( '<%1$s id="site-title"><a href="%2$s" rel="home">%3$s</a></%1$s>', 
        is_front_page() && is_home() ? 'h1' : 'p', 
        esc_url( home_url( '/' ) ), 
        esc_html( get_bloginfo( 'name' ) ) 
      );
    }

  }
endif;


/* POST DATES
   ==================================================== */
if ( ! function_exists( 'alurra_posted_on' ) ) :
	// Returns the post date
	function alurra_posted_on() {

		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
			);
		
		echo '<li class="publish-date"><span class="publish-date-label">' . esc_html__( 'Posted on ', 'alurra' ) . '</span><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a></li>';
	}
endif;

/* UPDATED POST DATE
   ==================================================== */
if ( ! function_exists( 'alurra_updated' ) ) :
	function alurra_updated() {
		printf( 	
		'<li class="posted-update">' .	esc_html__( 'Updated <span>%s</span>', 'alurra' ) .'</li>', get_the_modified_date() );
	}
endif;


/* META AUTHOR INFO
   ==================================================== */
if ( ! function_exists( 'alurra_posted_by' ) ) :
	function alurra_posted_by() {
		printf(
			'<li class="byline"><span class="postauthor">%1$s </span><span class="author vcard"><a class="url fn n" href="%2$s">%3$s</a></span></li>',
			esc_html__( 'by', 'alurra' ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_html( get_the_author() )
		);
	}
endif;

/* META COMMENT COUNT & LINK
   ==================================================== */
if ( ! function_exists( 'alurra_comment_link' ) ) :
	function alurra_comment_link() {
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<li class="comments-link">&ndash;&nbsp;';
			/* translators: %s: Name of current post. Only visible to screen readers. */
			comments_popup_link( sprintf( __( 'Make a comment<span class="screen-reader-text"> on %s</span>', 'alurra' ), get_the_title() ) );

			echo '</li>';
		}
	}
endif;

/* META POST FORMAT
   ==================================================== */
if ( ! function_exists( 'alurra_post_format' ) ) :
	// Returns the post date
	function alurra_post_format() {
		
		$format = get_post_format();
		if ( current_theme_supports( 'post-formats', $format ) ) {		
			printf( '<li class="post-format"><a href="%1$s">%2$s</a></li>',
				
				esc_url( get_post_format_link( $format ) ),
				esc_html(get_post_format_string( $format ))				
			);
		}
	}
endif;

/* META EDIT LINK
   ==================================================== */
if ( ! function_exists( 'alurra_edit_link' ) ) :
	function alurra_edit_link() {
		edit_post_link(
			sprintf(
				/* translators: %s: Name of current post */
				__( 'Edit Post<span class="screen-reader-text">%s</span>', 'alurra' ),
				get_the_title()
			),
			'<li class="edit-link">',
			'</li>'
		);
	}
endif;

/* DISPLAY A SINGLE POST CATEGORY
   ==================================================== */
if ( ! function_exists( 'alurra_first_category' ) ) :
	function alurra_first_category() {	
		$category = get_the_category();
		$first_category = $category[0];
		echo sprintf( 		
		'<div class="cat-links"><a href="%s">%s</a></div>', get_category_link( $first_category ), $first_category->name ); // phpcs:ignore WordPress.Security.EscapeOutput
	}
endif;


/* DISPLAY ALL POST CATEGORIES
   ==================================================== */
if ( ! function_exists( 'alurra_post_categories' ) ) :
	function alurra_post_categories() {
			  $categories_list = get_the_category_list( esc_attr_x( ', ', 'Used between list items, there is a space after the comma.', 'alurra' ) );
			  if ( $categories_list ) {
				echo sprintf( '<div class="post-cat-links">' . esc_html__( 'Categories:  ', 'alurra' ) . ' %s</div>', $categories_list ); // phpcs:ignore WordPress.Security.EscapeOutput
			  }
	}
endif;

/* DISPLAY POST TAGS
   ==================================================== */
if ( ! function_exists( 'alurra_post_tags' ) ) :
	function alurra_post_tags() {	 
				$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'alurra' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<div class="post-tag-links">' . esc_html__( 'Tags %1$s', 'alurra' ) . '</div>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput
			}	
	}
endif;

/* DISPLAY FEATURED or CATEGORY LABEL
   ==================================================== */
if ( ! function_exists( 'alurra_featured_cat_labels' ) ) {
function alurra_featured_cat_labels() {
		$alurra_featured_label_text = get_theme_mod( 'alurra_featured_label_text', esc_html__('Featured', 'alurra' ) );
		
		if( is_sticky() && is_home() && ! is_paged() && !esc_attr(get_theme_mod( 'alurra_hide_featured_labels', 0 )) ) { 
		echo '<span class="featured-label">' . wp_kses_post( $alurra_featured_label_text ) . '</span>';
		
		}  else {
		
			alurra_first_category();

		}
	}
}


/* DISPLAY THE SUMMARY POST META INFO
   ==================================================== */
if ( ! function_exists( 'alurra_entry_meta' ) ) :

	function alurra_entry_meta() {

		echo '<ul class="post-details">' ;	
			
				alurra_post_format();			
				alurra_posted_on();	
				alurra_posted_by();	
				alurra_comment_link();		
				alurra_edit_link();
		
		echo '</ul>';
	}
endif;

/* DISPLAY MINI SUMMARY POST META INFO
   ==================================================== */
if ( ! function_exists( 'alurra_entry_mini_meta' ) ) :

	function alurra_entry_mini_meta() {

		echo '<ul class="post-details">' ;	
				alurra_posted_on();
		echo '</ul>';
	}
endif;


/* BIO INFO
   ==================================================== */
if ( ! function_exists( 'alurra_bio_info' ) ) :
  function alurra_bio_info() {

$alurra_view_posts_by_text = get_theme_mod( 'alurra_view_posts_by_text', esc_html__('View Posts By', 'alurra' ) );

echo '<div class="author-info">';
    printf( '<div class="author-avatar">%s</div>', get_avatar( get_the_author_meta( 'user_email' ), 150 ) ); 

echo '<div class="author-description">';
  printf( '<h3 class="author-heading section-heading">%s</h3>', sprintf( esc_html__( 'Published by %s', 'alurra' ), get_the_author() ) ); 
  echo '<p class="author-bio">';
      the_author_meta( 'description' ); 
   echo '</p><a class="author-link" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" rel="author">';
echo '<span class="author-link-label">' . wp_kses_post( $alurra_view_posts_by_text ), '</span>&nbsp;', get_the_author();
    echo '</a></div></div>';

  }
endif;


/* POST FOOTER
   ==================================================== */
if ( ! function_exists( 'alurra_entry_footer' ) ) :
  function alurra_entry_footer() {
  
		echo '<footer class="entry-footer">' ;
		
		// Post categories
		if (!esc_attr(get_theme_mod( 'alurra_hide_post_category_tags', 0 ))) {
			alurra_post_categories();
		}
		// Post tags
		if (!esc_attr(get_theme_mod( 'alurra_hide_post_tags', 0 ))) {
			alurra_post_tags();
		}
		
		echo '</footer>';

  }
endif;

/* DISPLAY OPTIONAL POST THUMBNAIL
	Wraps the post thumbnail in an anchor element on index views, 
	or a div element when on single views.
   ==================================================== */
	if ( ! function_exists( 'alurra_post_thumbnail' ) ) {
		function alurra_post_thumbnail() {
			if ( ! alurra_can_show_post_thumbnail() ) {
				return;
			}
			?>

			<?php 
			if ( is_single() ): ?>
		
				<figure class="post-thumbnail">
					<?php the_post_thumbnail( 'post-thumbnail', array(						
					'alt' => the_title_attribute( array( 
					'echo' => false )),
					) );	?>
				</figure>

			<?php elseif (is_page() ) : ?>
			
			<div class="row">
				<div class="col">
							<figure class="post-thumbnail">
						<?php the_post_thumbnail( 'post-thumbnail', array(						
						'alt' => the_title_attribute( array( 
						'echo' => false )),
						) );	?>
					</figure>
				</div>
			</div>
			
			<?php else : ?>

				<figure class="post-thumbnail">
					<a class="post-thumbnail-link" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
						<?php the_post_thumbnail( 'post-thumbnail', array(						
						'alt' => the_title_attribute( array( 
						'echo' => false )),
						) );	?>
					</a>
				</figure>

			<?php endif; ?>
			
		
			<?php
		}
	}
	
	
/* BLOG  NAVIGATION
	Navigation for the blog
   ==================================================== */
if ( ! function_exists( 'alurra_paging_nav' ) ) :
function alurra_paging_nav() {
  global $wp_query;

  // Don't print empty markup if there's only one page.
  if ( $wp_query->max_num_pages < 2 )
    return;
  ?>
  <nav class="navigation paging-navigation" role="navigation">
    <h1 class="screen-reader-text"><?php esc_html_e( 'Posts navigation', 'alurra' ); ?></h1>
    <div class="nav-links">

      <?php if ( get_next_posts_link() ) : ?>
      <div class="nav-previous"><?php next_posts_link( sprintf( '%s <span>%s</span>', is_rtl() ? alurra_get_icon_svg( 'ui', 'arrow_right' ) : alurra_get_icon_svg( 'ui', 'arrow_left' ), esc_html__( 'Older posts', 'alurra' ) ) ); ?></div>
      <?php endif; ?>

      <?php if ( get_previous_posts_link() ) : ?>
      <div class="nav-next"><?php previous_posts_link( sprintf( '<span>%s</span> %s', esc_html__( 'Newer posts', 'alurra' ), is_rtl() ? alurra_get_icon_svg( 'ui', 'arrow_left' ) : alurra_get_icon_svg( 'ui', 'arrow_right' ) ) ); ?></div>
      <?php endif; ?>

    </div><!-- .nav-links -->
  </nav><!-- .navigation -->
  <?php
}
endif;


/* POST NAVIGATION
	Navigation for full posts.
   ==================================================== */
if ( ! function_exists( 'alurra_post_pagination' ) ) :
	function alurra_post_pagination() {
	
        the_post_navigation( array(
          'next_text' => '<span class="nav-meta">' . ( is_singular( 'post' ) ? esc_html__( 'Next post', 'alurra' ) : esc_html__( 'Next', 'alurra' ) ) . '</span> <span class="post-title">%title</span>',
          'prev_text' => '<span class="nav-meta">' . ( is_singular( 'post' ) ? esc_html__( 'Previous post', 'alurra' ) : esc_html__( 'Previous', 'alurra' ) ) . '</span> <span class="post-title">%title</span>',
        ) ); 
		
	}
endif;


/* MULTIPAGE NAVIGATION
	Navigation for splitting posts or pages into more than one page.
   ==================================================== */	
if ( ! function_exists( 'alurra_multipage_pagination' ) ) :
	function alurra_multipage_pagination() {
	
		wp_link_pages( array(
			'before'      => '<div class="multi-page-links"><span class="multi-page-links-title">' . esc_html__( 'Pages:', 'alurra' ) . '</span>',
			'after'       => '</div>',
			'link_before' => '<span>',
			'link_after'  => '</span>',
			'pagelink'    => ' %',
			'separator'   => ', ',
		) );
	}
endif;